==> dyc-rpc-call-starter-1.0.0-20210915.064029-4-sources.jar: com/tydic/utils/npc/config/NpcConfigurableAdvisorConfig.java <==
package com.tydic.utils.npc.config;

import com.tydic.utils.npc.aop.NpcNativeRpcCallAdvice;
import com.tydic.utils.npc.properties.NpcNativeProperties;
import lombok.extern.slf4j.Slf4j;
import org.springframework.aop.aspectj.AspectJExpressionPointcutAdvisor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.util.StringUtils;

/**
 * 标题：NpcConfigurableAdvisorConfig
 * 说明：本机RPC调用切面配置
 * 时间：2021/9/3 15:02
 *
 * @author 何秀全
 */
@Slf4j
@Configuration
@ConditionalOnProperty(name = "npc.native.is-call", havingValue = "true")
@EnableConfigurationProperties(NpcNativeProperties.class)
public class NpcConfigurableAdvisorConfig {
    /**
     * 默认本机RPC切点位置
     */
    private static final String DEFAULT_NATIVE_RPC_PACKAGE = "com.tydic.utils.npc.aaa";
    /**
     * 本机RPC切点包路径分隔符
     */
    private static final String NATIVE_RPC_PACKAGE_DELIMITER = ",";
    /**
     * 本机RPC调用配置项
     */
    @Autowired
    private NpcNativeProperties npcNativeProperties;

    @Bean
    public AspectJExpressionPointcutAdvisor configurableAdvisor() {
        AspectJExpressionPointcutAdvisor advisor = new AspectJExpressionPointcutAdvisor();
        //组装切点规则
        StringBuilder expressionBuilder = null;
        if (StringUtils.hasText(npcNativeProperties.getPointcutPackage())) {
            if (npcNativeProperties.getPointcutPackage().contains(NATIVE_RPC_PACKAGE_DELIMITER)) {
                String[] nativeRpcPackageSplit = npcNativeProperties.getPointcutPackage().split(NATIVE_RPC_PACKAGE_DELIMITER);
                for (String nativeRpcPackageString : nativeRpcPackageSplit) {
                    if (StringUtils.hasText(nativeRpcPackageString)) {
                        if (null == expressionBuilder) {
                            expressionBuilder = new StringBuilder();
                            expressionBuilder.append("(execution(* ").append(nativeRpcPackageString).append("..*(..)))");
                        } else {
                            expressionBuilder.append(" || (execution(* ").append(nativeRpcPackageString).append("..*(..)))");
                        }
                    }
                }
            } else {
                expressionBuilder = new StringBuilder();
                expressionBuilder.append("(execution(* ").append(npcNativeProperties.getPointcutPackage()).append("..*(..)))");
            }
        }
        if (null == expressionBuilder) {
            expressionBuilder = new StringBuilder();
            expressionBuilder.append("(execution(* ").append(DEFAULT_NATIVE_RPC_PACKAGE).append("..*(..)))");
        }
        String expression = String.valueOf(expressionBuilder);
        advisor.setExpression(expression);
        advisor.setAdvice(new NpcNativeRpcCallAdvice(npcNativeProperties.getIsCall(), npcNativeProperties.getServerAddress()));
        log.info("本机RPC调用切面配置完成，是否启用本机RPC调用：{}；RPC Controller地址：{}；切点规则为：{}", npcNativeProperties.getIsCall(), npcNativeProperties.getServerAddress(), expression);
        return advisor;
    }
}

==> dyc-rpc-call-starter-3.2.3-20240724.085751-1-sources.jar: com/tydic/utils/npc/config/NpcConfigurableAdvisorConfig.java <==
package com.tydic.utils.npc.config;

import com.tydic.utils.npc.aop.NpcNativeRpcCallAdvice;
import com.tydic.utils.npc.properties.NpcNativeProperties;
import lombok.extern.slf4j.Slf4j;
import org.springframework.aop.aspectj.AspectJExpressionPointcutAdvisor;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.util.StringUtils;

/**
 * 标题：NpcConfigurableAdvisorConfig
 * 说明：本机RPC调用切面配置
 * 时间：2021/9/3 15:02
 *
 * @author 何秀全
 */
@Slf4j
@Configuration
@ConditionalOnProperty(name = "npc.native.is-open-aop", havingValue = "true")
@EnableConfigurationProperties(NpcNativeProperties.class)
public class NpcConfigurableAdvisorConfig {
    /**
     * 默认本机RPC切点位置
     */
    private static final String DEFAULT_NATIVE_RPC_PACKAGE = "com.tydic.utils.npc.aaa";
    /**
     * 本机RPC切点包路径分隔符
     */
    private static final String NATIVE_RPC_PACKAGE_DELIMITER = ",";
    /**
     * 本机RPC调用配置项
     */
    @Autowired
    private NpcNativeProperties npcNativeProperties;

    @Bean
    public AspectJExpressionPointcutAdvisor configurableAdvisor() {
        AspectJExpressionPointcutAdvisor advisor = new AspectJExpressionPointcutAdvisor();
        //组装切点规则
        StringBuilder expressionBuilder = null;
        if (StringUtils.hasText(npcNativeProperties.getPointcutPackage())) {
            if (npcNativeProperties.getPointcutPackage().contains(NATIVE_RPC_PACKAGE_DELIMITER)) {
                String[] nativeRpcPackageSplit = npcNativeProperties.getPointcutPackage().split(NATIVE_RPC_PACKAGE_DELIMITER);
                for (String nativeRpcPackageString : nativeRpcPackageSplit) {
                    if (StringUtils.hasText(nativeRpcPackageString)) {
                        if (null == expressionBuilder) {
                            expressionBuilder = new StringBuilder();
                            expressionBuilder.append("(execution(* ").append(nativeRpcPackageString).append("..*(..)))");
                        } else {
                            expressionBuilder.append(" || (execution(* ").append(nativeRpcPackageString).append("..*(..)))");
                        }
                    }
                }
            } else {
                expressionBuilder = new StringBuilder();
                expressionBuilder.append("(execution(* ").append(npcNativeProperties.getPointcutPackage()).append("..*(..)))");
            }
        }
        if (null == expressionBuilder) {
            expressionBuilder = new StringBuilder();
            expressionBuilder.append("(execution(* ").append(DEFAULT_NATIVE_RPC_PACKAGE).append("..*(..)))");
        }
        String expression = String.valueOf(expressionBuilder);
        advisor.setExpression(expression);
        advisor.setAdvice(new NpcNativeRpcCallAdvice(npcNativeProperties.getServerAddress()));
        log.info("本机RPC调用切面配置完成，是否启用本机RPC调用：{}；RPC Controller地址：{}；切点规则为：{}", npcNativeProperties.getIsOpenAop(), npcNativeProperties.getServerAddress(), expression);
        return advisor;
    }
}
